/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.action;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpSession;

import org.loom.i18n.Messages;
import org.loom.mapping.ActionMapping;
import org.loom.mapping.Event;
import org.loom.resolution.ResolutionFactory;
import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;
import org.loom.servlet.Scope;
import org.loom.tags.menu.SelectedMenuItemLocator;

/**
 * Encapsulates the objects associated to this request:  request,
 * response, current action mapping, etc.
 * 
 * @author Ignacio Coloma
 */
public class ActionContext {

	/** the request that is being currently processed */
	private LoomServletRequest request;

	/** the request that is being written */
	private LoomServletResponse response;
	
	/** the ResolutionFactory instance */
	private ResolutionFactory resolutionFactory;
	
	/** the current Event that is being executed */
	private Event event;
	
	private ServletContext servletContext;
	
	public LoomServletRequest getRequest() {
		return request;
	}

	/**
	 * Sets an attribute for the given scope
	 * @param name the name of the attribute
	 * @param value the value of the attribute
	 * @param scope the scope where the attribute should be stored. PAGE is not allowed here.
	 */
	public void setAttribute(String name, Object value, Scope scope) {
		request.setScopedAttribute(name, value, scope);
	}
	
	/**
	 * Gets the value of the requested attribute for the given scope
	 * @param name the name of the attribute
	 * @param scope the scope where the attribute should be stored. PAGE is not allowed here.
	 */
	public Object getAttribute(String name, Scope scope) {
		return request.getScopedAttribute(name, scope);
	}
	
	/**
	 * Sets the currently selected menu item
	 */
	public void setSelectedMenuItem(String menuId, String menuItemId) {
		SelectedMenuItemLocator.setSelectedMenuItem(request, menuId, menuItemId);
	}
	
	/**
	 * Sets the currently selected menu item
	 */
	public void setSelectedMenuItem(String menuId, Class<? extends Action> actionClass, String event) {
		SelectedMenuItemLocator.setSelectedMenuItem(request, menuId, actionClass, event);
	}
	
	public Event getEvent() {
		return event;
	}
	
	public ActionMapping getActionMapping() {
		return event.getActionMapping();
	}
	
	public HttpSession getSession() {
		return request.getSession();
	}
	
	public HttpSession getSession(boolean create) {
		return request.getSession(create);
	}
	
	public void setRequest(LoomServletRequest request) {
		this.request = request;
	}

	public LoomServletResponse getResponse() {
		return response;
	}

	public void setResponse(LoomServletResponse response) {
		this.response = response;
	}

	public ResolutionFactory getResolutionFactory() {
		return resolutionFactory;
	}

	public void setResolutionFactory(ResolutionFactory resolutionFactory) {
		this.resolutionFactory = resolutionFactory;
	}

	public ServletContext getServletContext() {
		return servletContext;
	}

	public void setServletContext(ServletContext servletContext) {
		this.servletContext = servletContext;
	}

	/**
	 * @return the list of messages of this request
	 */
	public Messages getMessages() {
		return request.getParsedAction().getMessages();
	}
	
	/**
	 * @return true if any error occurred processing this request 
	 */
	public boolean hasError() {
		return !getMessages().isEmpty();
	}
	/*
	public Message addError( String messageKey){
		return addError(null, messageKey);
	}
	
	public Message addError(String normalizedPropertyPath, String messageKey){
		return getMessages().error(normalizedPropertyPath, messageKey);
	}
	
	public void addError( Message message){
		getMessages().addMessage(message);
	}*/
	
	public void setEvent(Event event) {
		this.event = event;
	}


}
