/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.loom.converter.Converter;
import org.loom.converter.LocaleUnawareConverter;
import org.loom.converter.NullConverter;


/**
 * Annotation for Maps
 * @author Ignacio Coloma
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.FIELD, ElementType.METHOD})
@Documented
public @interface MapMetadata {

	/** 
	 * Converter of the key value. If unspecified, will be guessed using the keyClass.
	 */ 
	Class<? extends LocaleUnawareConverter> keyConverter() default NullConverter.class;
	
	/** 
	 * For end nodes, the Converter for each Map value. If unspecified, will be guessed using the valueClass.
	 */ 
	Class<? extends Converter> valueConverter() default NullConverter.class;
	
}
