/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.util.Map;

import org.loom.annotation.Cache;
import org.loom.interceptor.CacheInterceptor;
import org.loom.mapping.ActionMapping;
import org.loom.mapping.Event;
import org.loom.validator.PathMatcher;

/**
 * Process Cache annotations
 * @author icoloma
 */
public class CacheAnnotationProcessor extends AbstractOncePerClassAnnotationProcessor {

	@Override
	protected void process(ActionMapping actionMapping) {
		for (Method method : actionMapping.getActionClass().getMethods()) {
			Cache annotation = method.getAnnotation(Cache.class);
			if (annotation != null && !Modifier.isStatic(method.getModifiers())) {
				CacheInterceptor interceptor = createInterceptor();
				interceptor.setCacheMethod(method);
				PathMatcher matcher = new PathMatcher(annotation.on(), annotation.except());
				for (Map.Entry<String, Event> entry : actionMapping.getEvents().entrySet()) {
					if (matcher.matches(entry.getKey())) {
						entry.getValue().addInterceptor(interceptor);
					}
				}
			}
		}
	}

	protected CacheInterceptor createInterceptor() {
		return new CacheInterceptor();
	}

}
