/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import javax.inject.Singleton;

import org.loom.annotation.validation.ImageValidation;
import org.loom.interceptor.AbstractImageValidationInterceptor;
import org.loom.interceptor.DefaultImageValidationInterceptor;
import org.loom.mapping.Event;


/**
 * Processes {@link ImageValidation} annotations
 * 
 * @author Rafael Serrano
 *
 */
@Singleton
public class ImageValidationAnnotationProcessor extends AbstractAnnotationProcessor {
	
	@Override
	public void process(Event event) {
		ImageValidation annotation = event.getJavaMethod().getAnnotation(ImageValidation.class);
		if (annotation != null) {
			AbstractImageValidationInterceptor interceptor = createInterceptor();
			interceptor.setParameterName(annotation.parameterName());
			if (annotation.minWidth() != -1) {
				interceptor.setMinWidth(annotation.minWidth());
			}
			if (annotation.maxWidth() != -1) {
				interceptor.setMaxWidth(annotation.maxWidth());
			}
			if (annotation.minHeight() != -1) {
				interceptor.setMinHeight(annotation.minHeight());
			}
			if (annotation.maxHeight() != -1) {
				interceptor.setMaxHeight(annotation.maxHeight());
			}
			if (annotation.maxFileSize() != -1) {
				interceptor.setMaxFileSize(annotation.maxFileSize());
			}
			interceptor.setAllowedFormats(annotation.formats());
			event.addInterceptor(interceptor);
		}
	}

	protected AbstractImageValidationInterceptor createInterceptor() {
		return new DefaultImageValidationInterceptor();
	}

}
