/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import javax.inject.Singleton;
import javax.persistence.PersistenceContext;

import org.loom.annotation.RetrieveEntities;
import org.loom.annotation.RetrieveEntity;
import org.loom.interceptor.DefaultRetrieveEntityInterceptor;
import org.loom.interceptor.RetrieveEntityInterceptor;
import org.loom.mapping.Event;
import org.loom.persistence.ExtendedEntityManager;


/**
 * Processes {@link RetrieveEntity} annotations
 * @author icoloma
 *
 */
@Singleton
public class RetrieveEntityAnnotationProcessor extends AbstractPropertyAnnotationProcessor<RetrieveEntity, RetrieveEntities> {

	@PersistenceContext
	private ExtendedEntityManager entityManager;
	
	public RetrieveEntityAnnotationProcessor() {
		super(RetrieveEntity.class, RetrieveEntities.class);
	}

	@Override
	protected void process(Event event, RetrieveEntity annotation, String propertyPath) {
		RetrieveEntityInterceptor interceptor = createRetrieveEntityInterceptor();
		interceptor.setReadOnly(annotation.readOnly());
		if (annotation.idPropertyName().length() > 0) {
			interceptor.setIdPropertyName(annotation.idPropertyName());
		}
		interceptor.setPropertyPath(propertyPath);
		interceptor.setPropertyClass(event.getPropertyClass(propertyPath));
		event.addInterceptor(interceptor);
	}

	private RetrieveEntityInterceptor createRetrieveEntityInterceptor() {
		DefaultRetrieveEntityInterceptor interceptor = new DefaultRetrieveEntityInterceptor();
		interceptor.setEntityManager(entityManager);
		return interceptor;
	}
	

}
