/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.loom.action.Action;
import org.loom.annotation.SSLPolicyType;
import org.loom.interceptor.DefaultSSLPolicyInterceptor;
import org.loom.interceptor.SSLRedirectDataFactory;
import org.loom.mapping.Event;


/**
 * Processes the {@link org.loom.annotation.SSLPolicy} annotation
 * @author icoloma
 *
 */
@Singleton
public class SSLPolicyAnnotationProcessor extends AbstractAnnotationProcessor {

	private SSLPolicyType defaultPolicy = SSLPolicyType.DO_NOT_MODIFY;

	@Inject
	private SSLRedirectDataFactory sslPortResolver; 
	
	@Override
	public void process(Event event) {
		
		org.loom.annotation.SSLPolicy annotation = event.getJavaMethod().getAnnotation(org.loom.annotation.SSLPolicy.class);
		if (annotation != null) { 
			// event policy
			setPolicy(event, annotation.value());
		} else {
			Class<? extends Action> actionClass = event.getActionMapping().getActionClass();
			annotation = actionClass.getAnnotation(org.loom.annotation.SSLPolicy.class);
			if (annotation != null) {
				// class policy
				setPolicy(event, annotation.value());
			} else {
				// default policy
				setPolicy(event, this.defaultPolicy);
			}
		}
	}
	
	private void setPolicy(Event event, SSLPolicyType policy) {
		if (policy != SSLPolicyType.DO_NOT_MODIFY) {
			DefaultSSLPolicyInterceptor interceptor = createInterceptor();
			interceptor.setPolicy(policy);
			event.addInterceptor(interceptor);
		}
	}

	protected DefaultSSLPolicyInterceptor createInterceptor() {
		DefaultSSLPolicyInterceptor interceptor = new DefaultSSLPolicyInterceptor();
		interceptor.setSslPortResolver(sslPortResolver);
		return interceptor;
	}

	public void setDefaultPolicy(SSLPolicyType defaultPolicy) {
		this.defaultPolicy = defaultPolicy;
	}

	public void setSslPortResolver(SSLRedirectDataFactory sslPortResolver) {
		this.sslPortResolver = sslPortResolver;
	}


}
