/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import org.loom.action.Action;
import org.loom.mapping.Event;
import org.springframework.security.access.annotation.Secured;

/**
 * Processes Spring Security {@link Secured} annotations
 * 
 * @author icoloma
 */
public class SecuredAnnotationProcessor extends AbstractSecurityAnnotationProcessor {

	@Override
	public void process(Event event) {

		Secured annotation = event.getJavaMethod().getAnnotation(Secured.class);
		if (annotation != null) { // use method annotation
			setEventRoles(event, annotation.value());
		} else { // use class annotation
			Class<? extends Action> actionClass = event.getActionMapping().getActionClass();
			Secured securedClass = actionClass.getAnnotation(Secured.class);
			if (securedClass != null) {
				setEventRoles(event, securedClass.value());
			}
		}
	}
	
}
