/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.binding;


import org.loom.log.Log;
import org.loom.validator.ValidationRequest;

/**
 * A node that is a simple property with a single value
 * @author Ignacio Coloma
 *
 */
public class SimpleNode extends Node {
	
	private static Log log = Log.getLog(SimpleNode.class);
	
	@Override
	public void setValue(Object container, Object value, String[] propertyPath, int index) {
		log.trace("Visiting: ", propertyPath[index]);
		if (index == propertyPath.length - 1) { // end node
			getPropertyWrapper().set(container, value);
		} else { // intermediate node
			Object propertyValue = getPropertyWrapper().get(container, true);
			getChild().setValue(propertyValue, value, propertyPath, index + 1);
		}
	}

	@Override
	public Object getValue(Object container, String[] propertyPath, int propertyIndex) {
		if (propertyIndex == propertyPath.length - 1)  {
			return container == null? null : getPropertyWrapper().get(container);
		}
		Object propertyValue = getPropertyWrapper().get(container, false);
		return propertyValue == null? null : getChild().getValue(propertyValue, propertyPath, propertyIndex + 1);
	}
	
	@Override
	protected void applyValidationImpl(Object container, ValidationRequest request) {
		Object value = getPropertyWrapper().get(container);
		request.push(getPropertyName());
		if (isLeaf()) { 
			request.validate(value);
		} else { 
			getChild().applyValidation(value, request);
		}
		request.pop();
	}

}
