/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.config;

import java.util.Locale;

import javax.inject.Singleton;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.loom.servlet.names.CookieNames;
import org.loom.util.CookieUtils;
import org.loom.util.LocaleUtils;

/**
 * Locale stored in a cookie cookie.
 * @author icoloma
 */
@Singleton
public class CookieLocaleResolver implements LocaleResolver {

	/** the name of the cookie to get/set */
	private String cookieName = CookieNames.LOCALE;
	
	public Locale getLocale(HttpServletRequest request) {
		Cookie serializedLocale = CookieUtils.getCookie(cookieName, request.getCookies());
		if (serializedLocale != null) {
			return LocaleUtils.toLocale(serializedLocale.getValue());
		}
		return null;
	}

	public void setLocale(HttpServletResponse response, Locale locale) {
		Cookie cookie = new Cookie(cookieName, locale.toString());
		cookie.setMaxAge(10 * 365 * 24 * 60 * 60); // ten years ahead
		cookie.setPath("/");
		response.addCookie(cookie);
	}

	public void setCookieName(String cookieName) {
		this.cookieName = cookieName;
	}

}
