/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.converter;

import org.loom.i18n.Message;
import org.loom.i18n.Messages;
import org.loom.tags.FormInputTag;
import org.loom.util.PropertyUtils;

public abstract class AbstractConverter implements Converter {

	/** class of the values returned by this converter */
	protected Class<?> convertedClass;

	/** the CSS class that should be added to any field linked to a property using this Converetr, null for none */
	protected String cssClass;
	
	protected AbstractConverter(Class<?> convertedClass) {
		this.convertedClass = convertedClass;
	}

    /**
     * Adds a conversion error message
     * @param messageKey The key of the error message
     * @param paramValue The text that was trying to parse
     */
    public Message addErrorMessage(Messages messages, String paramName, String paramValue, String messageKey) {
    	Message message = new Message(messageKey, paramName);
    	message.addArg(Message.VALUE_ARG, paramValue);
    	message.addArg("converter", this);
    	message.addTranslatedArg(Message.PROPERTY_PATH_ARG, PropertyUtils.normalize(paramName));
    	messages.addMessage(message);
    	return message;
    }
	
	public Class<?> getConvertedClass() {
		return convertedClass;
	}
	
	public void setConvertedClass(Class<?> convertedClass) {
		this.convertedClass = convertedClass;
	}

	/**
	 * Add CSS class extracted from this converter return type (number, string, file) to the tag.
	 */
	public void decorate(FormInputTag tag) {
		tag.addCssClass(cssClass);
	}

	public String getCssClass() {
		return cssClass;
	}

	public void setCssClass(String cssClass) {
		this.cssClass = cssClass;
	}
}
