/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.converter;

import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.text.Format;

import org.loom.i18n.MessagesRepository;
import org.loom.servlet.names.CssClassNames;


public abstract class AbstractDecimalConverter extends AbstractFormatConverter {

	/** true to use grouping, false for not */
	private Boolean groupingUsed = null;

	public AbstractDecimalConverter(Class<?> convertedClass, String typeKey) {
		super(convertedClass, typeKey);
		setCssClass(CssClassNames.NUMBER);
	}
	
	@Override
	protected Format createFormat(MessagesRepository messagesRepository) {
		DecimalFormatSymbols symbols = messagesRepository.createDecimalFormatSymbols();
		DecimalFormat decimalFormat = new DecimalFormat(messagesRepository.getRequiredString(getFormatKey()), symbols);
		if (groupingUsed == null) {
			groupingUsed = Boolean.valueOf(messagesRepository.getString("loom.format.useGrouping"));
		}
		decimalFormat.setGroupingUsed(groupingUsed);
		return decimalFormat;
	}

	public void setGroupingUsed(boolean groupingUsed) {
		this.groupingUsed = groupingUsed;
	}

}
