package org.loom.converter;

import java.io.IOException;

import javax.inject.Inject;

import org.apache.commons.lang.StringUtils;
import org.codehaus.jackson.JsonGenerationException;
import org.codehaus.jackson.JsonProcessingException;
import org.codehaus.jackson.map.JsonMappingException;
import org.codehaus.jackson.map.ObjectMapper;
import org.codehaus.jackson.type.JavaType;
import org.loom.i18n.Messages;
import org.loom.i18n.MessagesRepository;
import org.loom.log.Log;

/**
 * Converts to/from a JSON representation of the given Object
 * @author icoloma
 *
 */
public class JsonConverter extends AbstractConverter {

	/** the Jackson ObjectMapper used for serializing and deserializing */
	@Inject
	private ObjectMapper mapper;
	
	/** if specified, serialization/deserialization will use this {@link JavaType} instance */
	private JavaType javaType;

	private static Log log = Log.getLog(JsonConverter.class);
	
	protected JsonConverter(Class<?> convertedClass) {
		super(convertedClass);
	}
	
	public Object getAsObject(String paramName, String paramValue, Messages messages, MessagesRepository repository) {
		try {
			return StringUtils.isEmpty(paramValue)? null : mapper.readValue(paramValue, javaType);
		} catch (JsonProcessingException e) {
			log.debug(e, e);
			addErrorMessage(messages, paramName, paramValue, "loom.conversion.malformedJSON")
				.addArg("e", e);
			return null;
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
	}

	public String getAsText(Object value, MessagesRepository repository) {
		try {
			return value == null? null : mapper.writeValueAsString(value);
		} catch (JsonGenerationException e) {
			throw new RuntimeException(e);
		} catch (JsonMappingException e) {
			throw new RuntimeException(e);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
	}

	public void setMapper(ObjectMapper mapper) {
		this.mapper = mapper;
	}

	public void setJavaType(JavaType javaType) {
		this.javaType = javaType;
	}

}
