package org.loom.converter;

import java.util.Collection;
import java.util.Map;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.codehaus.jackson.map.ObjectMapper;
import org.codehaus.jackson.map.type.TypeFactory;
import org.codehaus.jackson.type.JavaType;
import org.loom.annotation.JSON;
import org.loom.binding.AnnotationContainer;

@Singleton
public class JsonConverterFactory implements AnnotationDrivenConverterFactory<JSON> {

	@Inject
	private ObjectMapper objectMapper;
	
	public Class<JSON> getAnnotationClass() {
		return JSON.class;
	}

	@SuppressWarnings("unchecked")
	public Converter getConverter(AnnotationContainer container, JSON annotation) {
		Class propertyClass = container.getPropertyClass();
		JsonConverter jc = new JsonConverter(propertyClass);
		jc.setMapper(objectMapper);
		
		//if (annotation.value() != TypeReference.class) { // not really needed. See JsonConverterFactoryTest.
		//	jc.setJavaType(TypeFactory.type(annotation.value()));
		JavaType type;
		if (Collection.class.isAssignableFrom(propertyClass)) { 
			type = TypeFactory.collectionType(propertyClass, container.getItemMetadata(0).getItemClass());
		} else if (propertyClass.isArray()) {
			type = TypeFactory.arrayType(propertyClass);
		} else if (Map.class.isAssignableFrom(propertyClass)) {
			type = TypeFactory.mapType(propertyClass, container.getItemMetadata(0).getItemClass(), container.getItemMetadata(1).getItemClass());
		} else {
			type = TypeFactory.type(propertyClass);
		}
		jc.setJavaType(type);
		return jc;
	}

	public void setObjectMapper(ObjectMapper objectMapper) {
		this.objectMapper = objectMapper;
	}

}
