/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.converter.date;

import java.text.Format;
import java.text.ParsePosition;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.loom.converter.AbstractFormatConverter;
import org.loom.i18n.MessagesRepository;
import org.loom.servlet.names.CssClassNames;
import org.loom.tags.FormInputTag;
import org.loom.tags.core.AbstractTextFieldTag;


/**
 * Converts a time string in the form hh:MM to an int with the number of minutes 
 * since the beginning of the day
 * @author icoloma
 */
public final class MinutesConverter extends AbstractFormatConverter {
	
	/** expected hh:mm format */
	private static Pattern pattern = Pattern.compile("^(\\d?\\d):(\\d?\\d)$");

	public MinutesConverter() {
		super(Integer.class, "loom.format.time", "loom.conversion.timeFailed");
		setCssClass(CssClassNames.TIME);
	}
	
	@Override
	protected Object parse(String text, ParsePosition pos, MessagesRepository repository) {
		int hours = -1;
		int minutes = -1;
		Matcher matcher = pattern.matcher(text);
		if (matcher.matches()) {
			hours = Integer.parseInt(matcher.group(1));
			minutes = Integer.parseInt(matcher.group(2));
		}
		if (hours >= 0 && hours < 24 && minutes >= 0 && minutes < 60) {
			pos.setIndex(text.length());
			return Integer.valueOf(hours * 60 + minutes);
		}
		return null;
	}
	
	@Override
	public String getAsTextImpl(Object v, MessagesRepository repository) {
		int value = (Integer)v;
		String hours = value < 60? "00" : String.valueOf(value / 60);
		String minutes = String.valueOf(value % 60);
		StringBuilder b = new StringBuilder(5);
		if (hours.length() < 2) {
			b.append('0');
		}
		b.append(hours);
		b.append(':');
		if (minutes.length() < 2) {
			b.append('0');
		}
		b.append(minutes);
		return b.toString();
	}
	
	@Override
	protected Format createFormat(MessagesRepository messagesRepository) {
		return null;
	}
	
	@Override
	public void decorate(FormInputTag t) {
		super.decorate(t);
		if (t instanceof AbstractTextFieldTag) {
			AbstractTextFieldTag tag = (AbstractTextFieldTag)t;
			if (tag.getMaxlength() == null) {
				tag.setMaxlength(5); // hh:MM
			}
		}
	}
		
}

