package org.loom.guice;

import java.util.Set;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.codehaus.jackson.map.ObjectMapper;
import org.codehaus.jackson.map.SerializationConfig;
import org.codehaus.jackson.map.annotate.JsonDeserialize;
import org.codehaus.jackson.map.annotate.NoClass;
import org.loom.log.Log;

@Singleton
public class GuiceObjectMapper extends ObjectMapper {

	private static Log log = Log.getLog(GuiceObjectMapper.class);
	
	/**
	 * The key is the data class, the value is the mixin class
	 * @param mixins
	 */
	@Inject 
	public void setMixins(@JacksonMixins Set<Class> mixins) {
		SerializationConfig serializationConfig = getSerializationConfig();
		for (Class mixin : mixins) {
			JsonDeserialize deserialize = (JsonDeserialize) mixin.getAnnotation(JsonDeserialize.class);
			if (deserialize == null || deserialize.as() == NoClass.class) {
				throw new IllegalArgumentException("Cannot inject Jackson mixin " + mixin.getClass().getName() + "; injected mixins must include a @JsonDeserialize.as() attribute indicating the serialized class type to use");
			}
			log.debug("Adding jackson mixin: ", mixin.getName());
			serializationConfig.addMixInAnnotations(deserialize.as(), mixin);
		}
	}
	
}
