package org.loom.interceptor;

import org.loom.annotation.SSLPolicyType;
import org.loom.log.Log;
import org.loom.mapping.Event;
import org.loom.mapping.ParsedAction;
import org.loom.resolution.RedirectResolution;
import org.loom.resolution.RedirectResolutionImpl;
import org.loom.resolution.Resolution;
import org.loom.servlet.HttpMethod;
import org.loom.servlet.LoomServletRequest;
import org.loom.tags.Form;
import org.loom.tags.HtmlTag;
import org.loom.tags.Link;
import org.loom.url.UrlBuilder;
import org.loom.validator.FormDecorator;
import org.loom.validator.LinkDecorator;

public class DefaultSSLPolicyInterceptor implements LinkDecorator, FormDecorator, PopulateInterceptor  {
	
	private SSLRedirectDataFactory sslPortResolver;
	
	/** the expected SSLPolicy */
	private SSLPolicyType policy;
	
	private static Log log = Log.getLog(DefaultSSLPolicyInterceptor.class);
	
	public Resolution beforePopulate(ParsedAction action) {
		LoomServletRequest request = action.getRequest();
		
		SSLRedirectData redirect = sslPortResolver.getRedirectData(request, policy);
		
		if (redirect != null) {
			if (request.getHttpMethod() != HttpMethod.GET) {
				throw new RuntimeException("Request does not have the correct protocol (expected: " + redirect.getScheme() + " on port " + redirect.getPort() + ". Since this is a " + request.getHttpMethod() + " request, we cannot redirect and just panic");
			}
			log.debug("Redirecting request to ", redirect);
			
			Event event = action.getEvent();
			RedirectResolution resolution = new RedirectResolutionImpl(event.getActionMapping().getActionClass(), event.getName());
			resolution.setScheme(redirect.getScheme());
			resolution.setPort(redirect.getPort());
			resolution.setHostname(redirect.getHostname());
			resolution.setIncludeRequestParameters(true);
			return resolution;
		}
		
		return null;
	}

	/**
	 * If the current request does not have the expected protocol (http/https),
	 * modify the links pointing to this event.
	 */
	public void decorate(Link link) {
		decorate(link.getUrl(), link);
	}
	
	/**
	 * If the current request does not have the expected protocol (http/https),
	 * modify the forms pointing to this event.
	 */
	public void decorate(Form form) {
		decorate(form.getUrl(), form);
	}

	protected void decorate(UrlBuilder url, HtmlTag tag) {
		LoomServletRequest request = tag.getRequest();
		boolean secure = request.isSecure();
		Integer redirectPort = null;
		SSLRedirectData redirect = null;
		if (secure && policy == SSLPolicyType.REQUIRES_INSECURE ||
				!secure && policy == SSLPolicyType.REQUIRES_SECURE) {
			redirect = sslPortResolver.getRedirectData(request, policy);
		}
		if (redirect != null) {
			url.setScheme(redirect.getScheme());
			url.setHostname(redirect.getHostname());
			url.setPort(redirect.getPort());
		}
	}
	
	@Override
	public String toString() {
		return "SSLPolicyInterceptor { " + policy + " }"; 
	}

	public SSLPolicyType getPolicy() {
		return policy;
	}

	public void setPolicy(SSLPolicyType policy) {
		this.policy = policy;
	}

	public void setSslPortResolver(SSLRedirectDataFactory sslPortResolver) {
		this.sslPortResolver = sslPortResolver;
	}
}
