package org.loom.interceptor;

import static org.loom.servlet.names.CssClassNames.UNAUTHORIZED;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.loom.log.Log;
import org.loom.mapping.ParsedAction;
import org.loom.resolution.Resolution;
import org.loom.security.SecurityAdapter;
import org.loom.tags.Button;
import org.loom.tags.HtmlTag;
import org.loom.tags.Link;
import org.loom.validator.ButtonDecorator;
import org.loom.validator.LinkDecorator;

/**
 * Checks that the user has the required roles to call the event.
 * This instance should be injected with scope prototype
 * @author icoloma
 */
public class DefaultSecurityInterceptor implements SecurityInterceptor, LinkDecorator, ButtonDecorator, CreateInterceptor {

	/** the class that will do the security validation */
	private SecurityAdapter securityAdapter;
	
	/** the list of roles allowed to invoke this event */
	private String[] allowedRoles;
	
	private static Log log = Log.getLog(DefaultSecurityInterceptor.class);
	
	public void decorate(Link link) {
		decorateImpl(link);
	}
	
	public void decorate(Button button) {
		decorateImpl(button);
	}
	
	/**
	 * Add the "unauthorized" css class to any link/submit button/menu item that points to this event
	 */
	private void decorateImpl(HtmlTag tag) {
		if (!securityAdapter.hasRole(allowedRoles)) {
			tag.addCssClass(UNAUTHORIZED);
		}
	}
	
	public Resolution afterCreate(ParsedAction action) {
		if (!securityAdapter.hasRole(allowedRoles)) {
			log.debug("Rejecting request because the user does not have any of the roles ", allowedRoles);
			securityAdapter.throwInsufficientPermissionsException("The user does not have enough permissions");
		}
		
		return null;
	}

	public String[] getAllowedRoles() {
		return allowedRoles;
	}

	public void setAllowedRoles(String[] allowedRoles) {
		this.allowedRoles = allowedRoles;
	}

	public void setSecurityAdapter(SecurityAdapter securityAdapter) {
		this.securityAdapter = securityAdapter;
	}

	@Override
	public String toString() {
		return new ToStringBuilder(this).append("allowedRoles", allowedRoles).toString(); 
	}
	
}
