/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.mapping;

import java.util.Collection;

import org.loom.action.Action;
import org.loom.servlet.LoomServletRequest;



/**
 * Repository of all configured {@link ActionMapping} instances.
 *  
 * @author Ignacio Coloma
 */
public interface ActionMappingRepository {

	public Collection<String> getMappings();
	
	public String getHandle(String uri);

	void addActionMapping(ActionMapping mapping);
	
	/**
	 * @param actionClass the action class
	 * @return the required actionMapping
	 * @throws IllegalArgumentException if there is no action registered with that class name
	 */
	public ActionMapping getActionMappingByClass(Class<? extends Action> actionClass);

	
	/**
	 * @param actionClassName the class name OR the unqualified class name (without the package path)
	 * @return the actionMapping
	 * @throws IllegalArgumentException if there is no action registered with that class name
	 */
	public ActionMapping getActionMappingByName(String actionClassName);

	/**
	 * @param uri the uri as returned by request.getServletPath()
	 * @param request the current request object
	 * @return the ActionMapping corresponding to this request, null if no Action was a match
	 */
	public Event getEvent(String uri, LoomServletRequest request);
	
	/**
	 * Remove the action mapping for one action class
	 * @param actionClass the action class to be removed
	 * @return the removed ActionMapping instance, null if not found
	 */
	public ActionMapping removeActionMapping(Class<? extends Action> actionClass);

	/**
	 * Validate the registered ActionMappings to check that there are no two 
	 * overlapping events that may produce the same URL 
	 */
	public void validateActionMappings();

}
