package org.loom.paged;

import org.loom.exception.HttpException;
import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.names.RequestParameterNames;

public class PagedListCriteriaFactory {
	
	/**
	 * Create a criteria instance for the current request
	 * @param request the current request object
	 */
	public static PagedListCriteria create (LoomServletRequest request) {
		return create(request, null);
	}
	
	/**
	 * Create a criteria instance
	 * @param id - the id of the paged container. This value will be used to disambiguate if more than one container is used on the same page
	 * @param pagedIndex - the index of the current page, starts with 0
	 * @param pagedSortProperty - sort property name
	 * @param pagedSortOrdersort - direction
	 */
	public static PagedListCriteria create ( String id, Integer pagedIndex, String pagedSortProperty, String pagedSortOrder) {
		PagedListCriteriaImpl criteria = new PagedListCriteriaImpl();
		criteria.setId(id);
		criteria.setPageIndex(pagedIndex);
		criteria.setSortProperty(pagedSortProperty);
		criteria.setSortOrder(SortOrder.fromValue(pagedSortOrder));
		return criteria;
	}
	
	/**
	 * Create a criteria instance for the current request, with disambiguation
	 * @param request the current request object
	 * @param id the paged container id. Null if there is only one paged container in this page.
	 */
	public static PagedListCriteria create (LoomServletRequest request, String id) {
		PagedListCriteriaImpl criteria = new PagedListCriteriaImpl();
		criteria.setId(id);
		String pi = id == null? RequestParameterNames.PAGED_INDEX : RequestParameterNames.PAGED_INDEX + "-" + id;
		String sp = id == null? RequestParameterNames.PAGED_SORT_PROPERTY : RequestParameterNames.PAGED_SORT_PROPERTY + "-" + id;
		String pso = id == null? RequestParameterNames.PAGED_SORT_ORDER : RequestParameterNames.PAGED_SORT_ORDER + "-" + id;
		
		Integer pagedIndex = 0;
		String s = request.getParameter(pi);
		if (s != null) {
			try {
				pagedIndex = Integer.parseInt(s);
			} catch (NumberFormatException e) {
				throw new HttpException(400, "Malformed value specified for " + pi, e);
			}
		}
		
		return create(id, pagedIndex, request.getParameter(sp), request.getParameter(pso));
	}
	
}
