package org.loom.persistence;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.Map;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 * Create the concrete ExtendedEntityManager implementation according to the provided EntityManager.
 * This factory will be needed until/if SPR-5285 gets accepted:
 * http://jira.springframework.org/browse/SPR-5285
 * 
 * @author icoloma
 *
 */
public class ExtendedEntityManagerFactory implements EntityManagerFactory {

	private EntityManagerFactory delegateFactory;
	
	private Constructor<? extends ExtendedEntityManager> constructor;
	
	public ExtendedEntityManagerFactory(EntityManagerFactory delegateFactory, Class<? extends ExtendedEntityManager> entityManagerClass) {
		try {
			this.delegateFactory = delegateFactory;
			this.constructor = entityManagerClass.getConstructor(EntityManager.class);
		} catch (NoSuchMethodException e) {
			throw new RuntimeException(e);
		}
	}
	
	public EntityManager createEntityManager() {
		EntityManager entityManager = delegateFactory.createEntityManager();
		return createExtendedEntityManager(entityManager);
	}
	
	@SuppressWarnings("unchecked")
	public EntityManager createEntityManager(Map map) {
		return createExtendedEntityManager(delegateFactory.createEntityManager(map));
	}
	
	private ExtendedEntityManager createExtendedEntityManager(EntityManager delegate) {
		try {
			return constructor.newInstance(delegate);
		} catch (InstantiationException e) {
			throw new RuntimeException(e);
		} catch (IllegalAccessException e) {
			throw new RuntimeException(e);
		} catch (InvocationTargetException e) {
			throw new RuntimeException(e.getCause());
		}
	}

	public void close() {
		delegateFactory.close();
	}

	public boolean isOpen() {
		return delegateFactory.isOpen();
	}
	
}
