/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.persistence.file;

import java.io.InputStream;

/**
 * Extends PersistentFile adding the file contents as an InputStream.
 * File contents are kept apart to avoid them from being loaded eagerly. Lazy loading in some JPA
 * containers (e.g. hibernate) required class code post-processing.
 * @author icoloma
 */
public interface PersistentFileContents {

	/**
	 * @return the file contents as an InputStream
	 */
	public InputStream getContentsAsStream();
	
	/**
	 * @return the file size if known, null if cannot be calculated from the file contents (it must be handled elsewhere in that case).
	 */
	public Long getFileSize();
	
}
