/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.resolution;

import java.io.IOException;

import javax.servlet.ServletException;

import org.loom.exception.HttpThrowable;
import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;
import org.loom.servlet.names.RequestAttributeNames;

/**
 * Return an http error code (404, 401, etc)
 * @author icoloma
 */
public class HttpErrorResolution extends AbstractHttpResolution {

	/** the http status code that should be returned */
	private int statusCode;
	
	/** the java exception, if any */
	private Throwable exception;
	
	public HttpErrorResolution(int statusCode) {
		this(statusCode, null);
	}
	
	public HttpErrorResolution(int statusCode, Throwable exception) {
		this.statusCode = statusCode;
		this.exception = exception;
	}
	
	public HttpErrorResolution(HttpThrowable httpException) {
		this(httpException.getHttpError(), httpException.getCause());
	}

	@Override
	public void resolve(LoomServletRequest request, LoomServletResponse response)
			throws IOException, ServletException {
		if (exception != null) {
			request.setAttribute(RequestAttributeNames.JAVA_EXCEPTION, exception);
		}
		response.sendError(statusCode);
	}

	public Throwable getException() {
		return exception;
	}

}
