package org.loom.resolution;

import java.net.MalformedURLException;
import java.util.Locale;

import javax.servlet.ServletContext;

import org.loom.servlet.LoomServletRequest;
import org.loom.util.LocaleUtils;

/**
 * Forward a request to the specified locale-specific resource.
 * 
 * A forward to "myfile.jsp" with spanish request locale and english default locale 
 * will first try "myfile_es.jsp", then "myfile_en.jsp" and, if none is found, "myfile.jsp"
 * 
 * @author icoloma
 *
 */
public class LocaleForwardResolution extends DefaultForwardResolution {

	/** the expected forward location suffix */
	private String resourceSuffix = ".jsp";
	
	private ServletContext servletContext;
	
	private Locale defaultLocale;
	
	@Override
	public String calculateTargetResource(LoomServletRequest request) {
		try {
			
			String target = super.calculateTargetResource(request);
			if (target.endsWith(resourceSuffix)) {
				String prefix = target.substring(0, target.length() - resourceSuffix.length());
				Iterable<String> filenames = LocaleUtils.getLocalizedFilenames(prefix, ".jsp", request.getLocale(), defaultLocale);
				for (String candidate : filenames) {
					if (servletContext.getResource(candidate) !=  null) {
						return candidate;
					}
				}
				
			}
			return target;
			
		} catch (MalformedURLException e) {
			throw new RuntimeException(e);
		}
	}

	public void setResourceSuffix(String resourceSuffix) {
		this.resourceSuffix = resourceSuffix;
	}

	public void setServletContext(ServletContext servletContext) {
		this.servletContext = servletContext;
	}

	public void setDefaultLocale(Locale defaultLocale) {
		this.defaultLocale = defaultLocale;
	}
	
}
