package org.loom.resources;

import java.io.ByteArrayInputStream;
import java.io.InputStream;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

/**
 * Implementation of WebResourceData that stores the result files in disk.
 * @author icoloma
 *
 */
public class CompiledInMemoryWebResource extends AbstractCompiledWebResource {
	
	/** the uncompressed resource contents */
	private byte[] contents;
	
	/** the gzipped resource contents */
	private byte[] gzippedContents;

	public InputStream getGzippedInputStream() {
		return new ByteArrayInputStream(gzippedContents);
	}

	public InputStream getInputStream() {
		return new ByteArrayInputStream(contents);
	}

	public long getGzippedLength() {
		return gzippedContents.length;
	}

	public long getLength() {
		return contents.length;
	}

	public void setContents(byte[] contents) {
		this.contents = contents;
	}

	public void setGzippedContents(byte[] gzippedContents) {
		this.gzippedContents = gzippedContents;
	}
	
	@Override
	public String toString() {
		return new ToStringBuilder(this, ToStringStyle.SHORT_PREFIX_STYLE)
			.append("contents", contents.length + " bytes")
			.append("gzippedContents", gzippedContents.length + " bytes")
			.append("name", name)
			.append("md5", md5)
			.toString();
	}

}
