package org.loom.resources;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.SortedMap;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.core.io.Resource;
import org.springframework.core.io.ResourceLoader;

import com.google.common.collect.Maps;

@Singleton
public class PrecompiledWebResourceBundleFactory implements WebResourceBundleFactory {

	/** the compiled index contents (key is the bundlename, value is the resource location) */
	private SortedMap<String, String> bundles = Maps.newTreeMap();
	
	@Inject
	public PrecompiledWebResourceBundleFactory(ResourceLoader resourceLoader, String compiledIndexLocation) {
		if (StringUtils.isEmpty(compiledIndexLocation)) { // bugfix: guice is passing an empty string
			compiledIndexLocation = "compiled/resources-index.properties";
		}
		Resource compiledIndex = resourceLoader.getResource(compiledIndexLocation);
		if (!compiledIndex.exists()) {
			throw new IllegalArgumentException(compiledIndexLocation + " does not exist. You must precompile your resources first.");
		}
		InputStream input = null;
		try {
			input = compiledIndex.getInputStream();
			Properties props = new Properties();
			props.load(input);
			for (Map.Entry<Object, Object> entry : props.entrySet()) {
				String name = (String) entry.getKey();
				String location = (String) entry.getValue();
				bundles.put(name, location);
			}
		} catch (IOException e) {
			throw new RuntimeException(e);
		} finally {
			IOUtils.closeQuietly(input);
		}
	}

	@Override
	public WebResourceBundle create(String n) {
		String name = StringUtils.substringAfterLast(n, "/");
		String location = bundles.get(name);
		if (location == null) {
			throw new IllegalArgumentException("No bundle found with name=" + name + ". Maybe you should recompile your web resources");
		}
		return new PrecompiledWebResourceBundle(name, location);
	}

	@Override
	public WebResourceBundle create(String name, List<Resource> resources) {
		throw new UnsupportedOperationException("Precompiled resources can only be defined using using @include from jsp pages or tag files");
	}

}
