package org.loom.resources;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import org.apache.commons.io.FileUtils;
import org.loom.log.Log;

/**
 * Compiles and store sthe result to disk
 * @author Nacho
 */
public class ToDiskWebResourceCompiler extends AbstractWebResourceCompiler {

	private boolean overwriteExistingFiles = false;
	
	private static Log log = Log.getLog(ToDiskWebResourceCompiler.class);
	
	@Override
	protected CompiledWebResource createCompiledWebResource(String name,
			String md5, String contents, byte[] gzippedContents) throws IOException {
		String tmpDir = System.getProperty("java.io.tmpdir");
		if (tmpDir.charAt(tmpDir.length() - 1) != File.separatorChar) {
			tmpDir += File.separatorChar;
		}
		String filename = tmpDir + "loom-" + md5 + "-" + name;
		log.debug("Storing WebResource [", name, "] at ", filename);
		File file = createOrOverwriteFile(filename, md5, contents.getBytes(charset));
		File gzFile = createOrOverwriteFile(filename + ".gz", md5, gzippedContents);

		CompiledToDiskWebResource result = new CompiledToDiskWebResource();
		result.setName(name);
		result.setFile(file);
		result.setGzippedFile(gzFile);
		result.setMd5(md5);
		return result;
	}
	
	private File createOrOverwriteFile(String filename, String md5, byte[] contents) throws IOException {
		File file = new File(filename);
		if (!file.exists() || overwriteExistingFiles) {
			FileOutputStream output = new FileOutputStream(file);
			FileUtils.writeByteArrayToFile(file, contents);
		}
		return file;
	}

	public void setOverwriteExistingFiles(boolean overwriteExistingFiles) {
		this.overwriteExistingFiles = overwriteExistingFiles;
	}

}
