package org.loom.resources.compressor;

import java.io.IOException;
import java.util.List;

import org.loom.exception.SyntaxError;

import com.google.common.collect.ImmutableList;
import com.google.javascript.jscomp.CompilationLevel;
import com.google.javascript.jscomp.Compiler;
import com.google.javascript.jscomp.CompilerOptions;
import com.google.javascript.jscomp.DefaultCodingConvention;
import com.google.javascript.jscomp.JSSourceFile;
import com.google.javascript.jscomp.Result;

/**
 * Adapter for Google Closure Compiler
 * @author icoloma
 */
public class ClosureJavascriptCompressorAdapter implements WebResourceCompressor {

	/** the fine-level compiler options to use. This is usually not needed */
	private CompilerOptions options;
	
	/** the CompilationLevel instance to use */
	private CompilationLevel compilationLevel;
	
	/** true to compile using threads (default true). Set to false to compile on AppEngine */
	private boolean useThreads = true;
	
	public ClosureJavascriptCompressorAdapter() {
		options = new CompilerOptions();
		setCompilationLevel(CompilationLevel.SIMPLE_OPTIMIZATIONS);
	}
	
	public String compress(String resourceName, String contents) throws IOException, SyntaxError {

	    // Compiler.setLoggingLevel(Level.parse(options.loggingLevel));
	    Compiler compiler = new Compiler();
	    if (!useThreads) {
			compiler.disableThreads();
		}
	    options.setCodingConvention(new DefaultCodingConvention()); // <-- do not obfuscate $super 
	    List<JSSourceFile> externFiles = ImmutableList.of();
		ImmutableList<JSSourceFile> inputFiles = ImmutableList.of(JSSourceFile.fromCode(resourceName, contents));
		Result result = compiler.compile(externFiles, inputFiles, options);
	    if (result.success) {
	    	return(compiler.toSource());
	    } else {
			throw new SyntaxError(null);
		}
	}

	public CompilerOptions getOptions() {
		return options;
	}

	public CompilationLevel getCompilationLevel() {
		return compilationLevel;
	}

	public void setCompilationLevel(CompilationLevel compilationLevel) {
		compilationLevel.setOptionsForCompilationLevel(this.options);
	}

	public void setUseThreads(boolean useThreads) {
		this.useThreads = useThreads;
	}

}
