/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.security;

import javax.inject.Singleton;

import org.loom.exception.HttpException;
import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletRequestImpl;

/**
 * Adapts standard JAAS
 * @author icoloma
 */
@Singleton
public class JeeSecurityAdapter implements SecurityAdapter {

	/**
	 * Calls the HttpServletRequest.isUserInRole() method for each allowedRole
	 */
	public boolean hasRole(String[] allowedRoles) {
		LoomServletRequest request = LoomServletRequestImpl.getThreadLocal();
		for (String role : allowedRoles) {
			if (request.isUserInRole(role)) {
				return true;
			}
		}
		return false;
	}
	
	/**
	 * This implementation will throw an instance of {@link HttpException}
	 */
	public void throwInsufficientPermissionsException(String message) {
		throw new HttpException(403, message);
	}

}
