/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.servlet;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletResponse;

/**
 * An enhanced implementation of the HttpServletResponse interface
 * @author icoloma
 *
 */
public interface LoomServletResponse extends HttpServletResponse {

	/**
	 * Delete a cookie on the browser
	 * @param name the name of the cookie to delete
	 */
	public void deleteCookie(String name);

	/**
	 * Note that this method will only return the status if it has been set 
	 * through this wrapper. Sometimes the server will change the status using the 
	 * underlying response instance.
	 * @return the status of this response object (200, 404, etc)
	 */
	public int getStatus();

	/**
	 * Adds a cookie  
	 * @param name the name of the cookie
	 * @param value the value of the Cookie
	 * @param expiry
	 *            can be positive (number of seconds that it will be stored in
	 *            the browser), zero (to delete the cookie from the browser) or
	 *            a negative value (to indicate that the cookie should not be
	 *            stored in disk and will be forgotten when the browser exists).
	 * @return the created Cookie instance
	 */
	Cookie addCookie(String name, String value, int expiry);

	/**
	 * Adds a cookie with a maxAge of -1  
	 * @param name the name of the cookie
	 * @param value the value of the Cookie
	 * @return the created Cookie instance
	 */
	Cookie addCookie(String name, String value);
	
}