/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.servlet;

import javax.servlet.jsp.PageContext;

/**
 * The web scope.
 * Supported scopes are:
 * <ul><li>Standard JEE scopes: page, request, session or application</li>
 * <li>Extended scopes: flash or conversation. These have an ID value greater than 1000, and are handled apart by Loom.</li></ul>
 * Declaration order is the order of fetching scopes, unless a  concrete scope has been specified.
 * @author icoloma
 */
public enum Scope {

	PAGE(PageContext.PAGE_SCOPE), 
	REQUEST(PageContext.REQUEST_SCOPE), 
	FLASH(1000),
	SESSION(PageContext.SESSION_SCOPE), 
	APPLICATION(PageContext.APPLICATION_SCOPE);
	
	/** if < 1000, this is the value used by the PageContext classes */
	private int id;
	
	/** the displayname is stored as lowercase */
	private String displayName;
	
	private Scope(int id) {
		this.id = id;
		this.displayName = this.name().toLowerCase();
	}

	public int getId() {
		return id;
	}
	
	@Override
	public String toString() {
		return displayName;
	}
	
	public static Scope fromString(String scope) {
		for (Scope candidate : Scope.values()) {
			if (candidate.displayName.equals(scope)) {
				return candidate;
			}
		}
		throw new IllegalArgumentException("No scope defined with name '" + scope + "'");
	}

	/**
	 * @return true if the scope is a standard JEE scope: page, request, session or application
	 */
	public boolean isJEE() {
		return id < 1000;
	}
	
}
