/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.servlet.names;

/**
 * Request HTTP header names. 
 * 
 * @author icoloma
 */
public interface RequestHeaderNames extends CommonHeaderNames {
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.1">Accept</a> */
	public static final String ACCEPT = "Accept";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.2">Accept-Charset</a> */
	public static final String ACCEPT_CHARSET = "Accept-Charset";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.3">Accept-Encoding</a> */
	public static final String ACCEPT_ENCODING = "Accept-Encoding";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4">Accept-Language</a> */
	public static final String ACCEPT_LANGUAGE = "Accept-Language";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.8">Authorization</a> */
	public static final String AUTHORIZATION = "Authorization";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.22">From</a> */
	public static final String FROM = "From";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.23">Host</a> */
	public static final String HOST = "Host";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.25">If-Modified-Since</a> */
	public static final String IF_MODIFIED_SINCE = "If-Modified-Since";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.26">If-None-Match</a> */
	public static final String IF_NONE_MATCH = "If-None-Match";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.28">If-Unmodified-Since</a> */
	public static final String IF_UNMODIFIED_SINCE = "If-Unmodified-Since";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.34">Proxy-Authorization</a> */
	public static final String PROXY_AUTHORIZATION = "Proxy-Authorization";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.36">Referer</a> (yes it's misspelled in the spec) */
	public static final String REFERER = "Referer";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.43">User-Agent</a> */
	public static final String USER_AGENT = "User-Agent";
	
	/** Added by Prototype and JQuery when launching ajax requests */
	public static final String X_REQUESTED_WITH = "X-Requested-With";
	
}
