/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.servlet.names;

/**
 * Response HTTP header names.
 * http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html
 * 
 * @author icoloma
 */
public interface ResponseHeaderNames extends CommonHeaderNames {
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.5">Accept-Ranges</a> */
	public static final String ACCEPT_RANGES = "Accept-Ranges";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.6">Age</a> */
	public static final String AGE = "Age";
	
	/** 
	 * Indicate the browser if the file should be opened or saved. Allowed values are "attachment" or "inline" 
	 * See <a href="http://www.ietf.org/rfc/rfc2183.txt">RFC2183</a> */
	public static final String CONTENT_DISPOSITION = "Content-disposition";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.11">Content-Encoding</a> */ 
	public static final String CONTENT_ENCODING = "Content-Encoding";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.12">Content-Language</a> */
	public static final String CONTENT_LANGUAGE = "Content-Language";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.15">Content-MD5</a> */
	public static final String CONTENT_MD5 = "Content-MD5";

	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.17">Content-type</a> */
	public static final String CONTENT_TYPE = "Content-Type";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.19">ETag</a> */
	public static final String ETAG = "ETag";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.21">Expires</a> */
    public static final String EXPIRES = "Expires";
    
    /** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.29">Last-Modified</a> */
    public static final String LAST_MODIFIED = "Last-Modified";

    /** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.30">Location</a> */
    public static final String LOCATION = "Location";
    
    /** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.32">Pragma</a> */
    public static final String PRAGMA = "Pragma";
    
    /** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.38">Server</a> */
    public static final String SERVER = "Server";
    
	/** <a href="http://www.eriksmartt.com/blog/archives/319">X-JSON</a> header used for JSON responses. */
	public static final String X_JSON = "X-JSON";

}
