/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.core;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.servlet.Scope;
import org.loom.tags.AbstractTag;
import org.loom.util.HtmlSanitizer;
import org.tldgen.annotations.Attribute;

/**
 * Parent of the out tags.
 * @author icoloma
 *
 */
public abstract class AbstractOutTag extends AbstractTag {

	/** true to translate the value before output, default true */
	@Attribute
	private boolean translate;
	
	/** true to print the value, default true */
	private boolean ifClause = true;
	
	/** if not null, the value will be stored as an attribute instead of rendered in the page */
	@Attribute
	private String var;
	
	private Scope scope = Scope.PAGE;
	
	/** true to escape HTML codes, default false for OutTag, and true for OutPropertyTag */
	@Attribute
	private boolean escapeHtml;

	/**
	 * @return the value that should get displayed
	 */
	protected abstract String getDisplayValue() throws JspException;

	@Override
	public void doTagImpl() throws JspException, IOException {
		String outString = getDisplayValue();
		if (outString != null) {
			if (translate) {
				outString = repository.guessString(outString);
				
				// evaluate any ${} after translating
				Object expr = evaluateExpression(outString);
				outString = expr == null? "" : expr.toString();
			}
			if (escapeHtml) {
				outString = HtmlSanitizer.sanitize(outString);
			}
			
			if (var != null) {
				// store in the scoped var and return
				setScopedAttribute(var, outString, scope);
			} else {
				// print the value
				out.print(outString);
			}
		}

    }
	
	/** 
	 * If var is not null, this is the scope where the value will be stored.
	 * Possible values are <code>page</code> (default), <code>request</code>,
	 * <code>session</code> and <code>application</code>.  
	 */
	@Attribute
	public void setScope(String scope) {
		this.scope = Scope.fromString(scope);
	}

	public void setEscapeHtml(boolean escapeHtml) {
		this.escapeHtml = escapeHtml;
	}

	public boolean isTranslate() {
		return translate;
	}

	public void setTranslate(boolean translate) {
		this.translate = translate;
	}

	public boolean isIf() {
		return ifClause;
	}

	/**
	 * False to skip tag execution (default true).
	 */
	@Attribute
	public void setIf(boolean ifClause) {
		this.ifClause = ifClause;
	}

	public String getVar() {
		return var;
	}

	public void setVar(String var) {
		this.var = var;
	}

	public boolean isEscapeHtml() {
		return escapeHtml;
	}


}