/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.core;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;


/**
 * <a href="http://www.w3.org/TR/html4/struct/links.html#edef-LINK">HTML CSS link</a>.
 * CSS files can be delivered one by one or bundled 
 * together as a web resource configured using your DI engine. 
 * @author icoloma
 */
@Tag(
	dynamicAttributes=true, 
	bodyContent=BodyContent.SCRIPTLESS,
	example=
		"&lt;l:css href=\"/css/ie7.css\" ieLessThan=\"7\"/>\n" +
		"&lt;l:css resource=\"styles\"/>"

)
public class CssTag extends AbstractWebResourceTag {

	/** see http://www.w3.org/TR/html4/present/styles.html#adef-media */
	@Attribute
	private String media;
	
	/** <a href="http://www.w3.org/TR/html4/struct/links.html#adef-rel">HTML attribute</a> */
	@Attribute
	private String rel;
	
	public CssTag() {
		this.rel = "stylesheet";
		this.setType("text/css");
	}
	
	@Override
	public void printTag() throws JspException, IOException {

		out.print("<link");
		out.printAttribute("href", getUrlBuilder().getURL());
		out.printAttribute("rel", rel);
		out.printAttribute("type", getType());
		out.printAttribute("media", media);
		out.print(">");
		out.print(getContents());
		out.print("</link>");
	}
	
	/** <a href="http://www.w3.org/TR/html4/interact/scripts.html#adef-src-SCRIPT">HTML attribute</a> */
	@Attribute
	public void setHref(String href) {
		setRawUrl(href);
	}

	public void setMedia(String media) {
		this.media = media;
	}

	public void setRel(String rel) {
		this.rel = rel;
	}

}
