/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.core;

import org.loom.config.ConfigProperties;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;


/**
 * <a href="http://www.w3.org/TR/html4/interact/forms.html#edef-INPUT">HTML password input field</a>.
 * These fields will print the existing value by default, if any; if that's a concern, just set the value attribute
 * to the empty String.
 * @author icoloma
 *
 */
@Tag(
		dynamicAttributes=true,
		bodyContent=BodyContent.EMPTY,
		example="&lt;l:inputText name=\"customer.password\"/>\n"
	)
public class InputPasswordTag extends InputTextTag {

	private static String DEFAULT_CSS = ConfigProperties.getInstance().getDefaultCss(InputPasswordTag.class, null);
	
	public InputPasswordTag() {
		setCssClass(DEFAULT_CSS);
		setType("password");
	}
	
}
