/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.core;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.tags.AbstractTag;
import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;

/**
 * An option inside a select or radio tag 
 * @author icoloma
 */
@Tag(
		dynamicAttributes=true,
		bodyContent=BodyContent.EMPTY,
		example="See <a href=\"inputSelect.html\">inputSelect</a> or <a href=\"inputRadio.html\">inputRadio</a>"
	)
public class OptionTag extends AbstractTag {

	/** the value to be used */
	@Attribute
	private String value;
	
	/** the label to display */
	@Attribute
	private String label;

	/** true to translate the option label before rendering. Default to the container attribute */
	@Attribute
	private Boolean translateLabel = null; 
	
	@Override
	public void doTagImpl() throws JspException, IOException {
		AbstractOptionsTag tag = getAncestorWithClass(AbstractOptionsTag.class);
		tag.addOption(value, label, translateLabel);
	}
	
	public void setLabel(String label) {
		this.label = label;
	}

	public void setValue(String value) {
		this.value = value;
	}


	public Boolean getTranslateLabel() {
		return translateLabel;
	}


	public void setTranslateLabel(Boolean translateLabel) {
		this.translateLabel = translateLabel;
	}

}
