/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.core;

import javax.servlet.jsp.JspException;

import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;

/**
 * Translates and prints a value.
 * It is typically used to print locale-specific output, but also 
 * includes limited support for simple if-else clauses.
 * @author icoloma
 */
@Tag(
	dynamicAttributes=true, 
	bodyContent=BodyContent.SCRIPTLESS,
	example=
		"&lt;l:out value=\"foo\"/>\n" +
		"&lt;l:out value=\"add\"\n" + 
		"	if=\"${!l:contains(items, item)}\"\n" +
		"	else=\"remove\"\n" +
		"/>"
)
public class OutTag extends AbstractOutTag {

	/** the string value to get translated */
	@Attribute(required=true)
	private String value;
	
	/** if the ifClause is false and else != null, write else instead of value */
	private String elseClause;

	public OutTag() {
		setTranslate(true);
	}
	
	@Override
	protected String getDisplayValue() throws JspException {
		Object output = isIf()? value : elseClause;
		return output == null? null : output.toString();
	}
	
	public String getElse() {
		return elseClause;
	}

	public String getValue() {
		return value;
	}

	/** 
	 * If the <code>if</code> clause is false and <code>else</code> is not null, 
	 * print else instead of value 
	 */
	@Attribute
	public void setElse(String elseClause) {
		this.elseClause = elseClause;
	}

	public void setValue(String value) {
		this.value = value;
	}

}
