/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.decorator;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.apache.commons.lang.StringUtils;
import org.loom.tags.AbstractFormInputTag;
import org.loom.tags.WriterWrapper;
import org.loom.tags.core.InputFileTag;
import org.loom.tags.core.InputImageTag;
import org.loom.tags.core.InputPasswordTag;
import org.loom.util.HtmlSanitizer;

/**
 * Renders the field as text, prepended with a span mimicking the label.
 * @author icoloma
 */
public class ReadOnlyDecorator<T extends AbstractFormInputTag> extends AbstractLoomDecorator<T> {

	@Override
	public boolean beforeDoTag(T tag) throws IOException, JspException {
		if (skipTag(tag)) {
			return false;
		}
		WriterWrapper<?> out = tag.getWriter();
		if ( tag.shouldRenderLabel() ){
			out.print("<p><span").printAttribute("class", "label").print(">");
			out.print(tag.getTranslatedLabel());
			out.print(": ");
			out.print("</span>\n");
		}
		
		String value = getValue(tag);
		if (!StringUtils.isEmpty(value)) {
			out.print("<span").printAttribute("class", "value").print(">");
			out.print(value);
			out.print("</span>\n");
		}
		
		if ( tag.shouldRenderLabel() ){
			out.print("</p>");
		}
		return false;
	}

	/** 
	 * @return true if this tag must be skipped, because a read-only form should not show it
	 */
	protected boolean skipTag(T tag) {
		return  tag instanceof InputFileTag || tag instanceof InputPasswordTag || tag instanceof InputImageTag;
	}

	private String getValue(T tag) throws JspException, IOException {
		String result = tag.renderAsText();
		if (tag.isEscapeHTML()) {
			result = HtmlSanitizer.sanitize(result);
		}
		return result;
	}

	@Override
	public void afterDoTag(T tag) throws IOException, JspException {
	}

}
