/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.decorator;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.tags.LoomTag;

/**
 * Decorates a tag, adding content before and after its render.
 * Implementing classes MUST BE THREAD SAFE.
 * The simple rule of thumb is that you better do not use any attributes in your decorators. 
 * @author icoloma
 */
public interface TagDecorator<T extends LoomTag> {

	/**
	 * @return true to execute the tag afterwards, false to skip the tag. If false,
	 * the afterDoTag method will not be triggered.
	 */
	public boolean beforeDoTag(T tag) throws IOException, JspException;
	
	public void afterDoTag(T tag) throws IOException, JspException;
	
}
