/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.url;

import javax.ws.rs.Path;



/**
 * A parameter container. This interface is implemented by tags that will generate a URL,
 * and will accept parameters to be appended to the URL by any nested &lt;l:param> tag
 * or any param-* attribute.
 * <p>
 * Provided parameters may be included as part of the URL is they are specified in the corresponding
 * {@link Path} annotation.
 * </p>
 * @author icoloma
 */
public interface ParameterContainer {

	/**
	 * Adds a parameter to the resulting url
	 * @param name the name of the parameter 
	 * @param value the value of the parameter 
	 * @return the same instance of ParameterContainer, to allow nested calls.
	 */
	public ParameterContainer addParameter(String name, Object value);
	
}
