/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.util;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.loom.i18n.CompiledMessage;
import org.loom.i18n.MessageCompiler;

/**
 * Resolves a template and a list of arguments into a result string.
 * @author icoloma
 */
public class TemplateResolver {

	Map<String, CompiledMessage> messages = new ConcurrentHashMap<String, CompiledMessage>();
	
	private static TemplateResolver instance = new TemplateResolver();
	
	public String resolve(String template, Map<String, Object> args) {
		CompiledMessage cm = messages.get(template);
		if (cm == null) {
			cm = MessageCompiler.compile(template);
			messages.put(template, cm);
		}
		return cm.eval(args);
	}

	public static TemplateResolver getInstance() {
		return instance;
	}

	public static void setInstance(TemplateResolver instance) {
		TemplateResolver.instance = instance;
	}
	
}
