package org.loom.util.displaytag;

import org.displaytag.pagination.PaginatedList;
import org.displaytag.properties.SortOrderEnum;
import org.loom.paged.PagedListCriteria;
import org.loom.paged.PagedListCriteriaImpl;
import org.loom.paged.PagedListData;
import org.loom.paged.SortOrder;
import org.loom.persistence.ExtendedEntityManager;

public class PaginatedListAdapter {

	private ExtendedEntityManager entityManager;
	
	public PaginatedListAdapter(ExtendedEntityManager entityManager) {
		this.entityManager = entityManager;
	}
	
	public <T> void query(PaginatedListImpl<T> page, String query, Object... params) {
		PagedListCriteria criteria = toCriteria(query, page);
		for (Object param : params) {
			criteria.addParameter(param);
		}
		PagedListData<T> data = entityManager.query(criteria);
		page.setList(data.getData());
		page.setTotal(data.getTotalRecords());
	}

	public static PagedListCriteria toCriteria(String query, PaginatedList list) {
		PagedListCriteriaImpl criteria = new PagedListCriteriaImpl();
		criteria.setSortProperty(list.getSortCriterion());
		criteria.setSortOrder(list.getSortDirection() == SortOrderEnum.DESCENDING? SortOrder.DESCENDING : SortOrder.ASCENDING);
		criteria.setPageIndex(list.getPageNumber() - 1);
		criteria.setPageSize(list.getObjectsPerPage());
		criteria.setQuery(query);
		return criteria;
	}
	
	public static <T> PaginatedListImpl<T> toPaginatedList(PagedListData<T> data) {
		PaginatedListImpl<T> result = new PaginatedListImpl<T>();
		result.setPageSize(data.getPageSize());
		result.setIndex(data.getPageIndex());
		result.setList(data.getData());
		result.setSortCriterion(data.getSortProperty());
		result.setSortDirection(data.getSortOrder() == SortOrder.DESCENDING? SortOrderEnum.DESCENDING : SortOrderEnum.ASCENDING);
		result.setTotal(data.getTotalRecords());
		return result;
	}
	
}
