/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.validator;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.loom.exception.InternalValidationException;
import org.loom.tags.FormInputTag;


/**
 * Calls a given method to validate
 * @author icoloma
 */
public class MethodValidator extends AbstractPropertyValidator {

	/** the validation method that must be called */
	private Method validateMethod;
	
	/**
	 * Calls the validation method 
	 * @param container The container of the method to be invoked
	 */
    public void validate(ValidationRequest request, Object container) {
		try {
			if (container != null) {
				validateMethod.invoke(container);
			}
		} catch (IllegalAccessException e) {
			throw new InternalValidationException(e);
		} catch (InvocationTargetException e) {
			throw new InternalValidationException(e.getTargetException());
		}
	}

	public void setValidateMethod(Method validateMethod) {
		this.validateMethod = validateMethod;
	}
	
    @Override
    public String toString() {
    	return new ToStringBuilder(this).append("validateMethod", validateMethod).toString();
    }

    @Override
    public void decorate(FormInputTag t) {
		// nothing to do here
	}

}
