/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.validator.date;

import org.joda.time.DateTime;
import org.joda.time.Period;

/**
 * A Date value that is calculated at runtime, because it is 
 * relative to the current date or any other field 
 * @author icoloma
 */
public class DateValue {

	/** the referral date: may be today or a constant field */
	private ReferralDate start;

	/** the period to be added or substracted from the start date */
	private Period delta;
	
	/** the original date expression parsed */
	private String parseExpression;
	
	public DateTime getDate() {
		DateTime result = start.getDate();
		return delta == null? result : result.plus(delta);
	}

	public void setDelta(Period delta) {
		this.delta = delta;
	}

	public void setStart(ReferralDate start) {
		this.start = start;
	}

	public void setParseExpression(String dateExpression) {
		this.parseExpression = dateExpression;
	}
	
	@Override
	public String toString() {
		return parseExpression;
	}

	public ReferralDate getStart() {
		return start;
	}
}
